######################
django-rest-email-auth
######################

.. image:: https://img.shields.io/travis/cdriehuys/django-rest-email-auth.svg
    :target: https://travis-ci.org/cdriehuys/django-rest-email-auth

.. image:: https://img.shields.io/codecov/c/github/cdriehuys/django-rest-email-auth.svg
    :target: https://codecov.io/gh/cdriehuys/django-rest-email-auth

.. image:: https://img.shields.io/pypi/v/django-rest-email-auth.svg
    :target: https://pypi.python.org/pypi/django-rest-email-auth/

***************
Important Links
***************

Project Homepage
  https://github.com/cdriehuys/django-rest-email-auth

Documentation
  https://django-rest-email-auth.readthedocs.io

********
Overview
********

This package provides a simple way to enable authentication with email addresses for a REST API.

Features:
  * Verification of user email addresses
  * Authentication using any of a user's verified email addresses
  * Registration of new users
  * Password resets using verified emails

***************
Adding Features
***************

This package was primarily developed for a single project's use. As such it may lack features that other projects require. If that is the case, please `open an issue <open-issue_>`_ and let us know.

*******
License
*******

This project is licensed under the MIT License.

*******
Authors
*******

Chathan Driehuys (chathan@driehuys.com)


.. _open-issue: https://github.com/cdriehuys/django-rest-email-auth/issues/new
